about summary refs log tree commit diff
path: root/src/libstd
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2014-08-23 14:30:57 +0000
committerbors <bors@rust-lang.org>2014-08-23 14:30:57 +0000
commit6843d8ccd562c5c5d45c0bba570908d5aa765610 (patch)
tree8110d5487f05c4193c86af69cb99dd491d990720 /src/libstd
parentf66fd2eed10de2acacd8af73c704bf4d140410bb (diff)
parent68811817f723e57354b0137b1c9bc6b28016ecbc (diff)
downloadrust-6843d8ccd562c5c5d45c0bba570908d5aa765610.tar.gz
rust-6843d8ccd562c5c5d45c0bba570908d5aa765610.zip
auto merge of #16693 : vadimcn/rust/rename--win32, r=pcwalton
Diffstat (limited to 'src/libstd')
-rw-r--r--src/libstd/dynamic_lib.rs1
-rw-r--r--src/libstd/io/mod.rs2
-rw-r--r--src/libstd/os.rs13
3 files changed, 7 insertions, 9 deletions
diff --git a/src/libstd/dynamic_lib.rs b/src/libstd/dynamic_lib.rs
index fb951d45c42..16c00d76c54 100644
--- a/src/libstd/dynamic_lib.rs
+++ b/src/libstd/dynamic_lib.rs
@@ -279,7 +279,6 @@ pub mod dl {
 }
 
 #[cfg(target_os = "windows")]
-#[cfg(stage0, target_os = "win32")] // NOTE: Remove after snapshot
 pub mod dl {
     use c_str::ToCStr;
     use iter::Iterator;
diff --git a/src/libstd/io/mod.rs b/src/libstd/io/mod.rs
index e93a958acc6..dc6478df360 100644
--- a/src/libstd/io/mod.rs
+++ b/src/libstd/io/mod.rs
@@ -348,7 +348,7 @@ impl IoError {
                 // libuv maps this error code to EISDIR. we do too. if it is found
                 // to be incorrect, we can add in some more machinery to only
                 // return this message when ERROR_INVALID_FUNCTION after certain
-                // win32 calls.
+                // Windows calls.
                 libc::ERROR_INVALID_FUNCTION => (InvalidInput,
                                                  "illegal operation on a directory"),
 
diff --git a/src/libstd/os.rs b/src/libstd/os.rs
index 7780c61e866..ad666d70034 100644
--- a/src/libstd/os.rs
+++ b/src/libstd/os.rs
@@ -139,7 +139,7 @@ pub fn getcwd() -> Path {
 }
 
 #[cfg(windows)]
-pub mod win32 {
+pub mod windows {
     use libc::types::os::arch::extra::DWORD;
     use libc;
     use option::{None, Option};
@@ -362,7 +362,7 @@ pub fn getenv_as_bytes(n: &str) -> Option<Vec<u8>> {
 pub fn getenv(n: &str) -> Option<String> {
     unsafe {
         with_env_lock(|| {
-            use os::win32::{fill_utf16_buf_and_decode};
+            use os::windows::{fill_utf16_buf_and_decode};
             let n: Vec<u16> = n.utf16_units().collect();
             let n = n.append_one(0);
             fill_utf16_buf_and_decode(|buf, sz| {
@@ -707,7 +707,7 @@ pub fn self_exe_name() -> Option<Path> {
     #[cfg(windows)]
     fn load_self() -> Option<Vec<u8>> {
         unsafe {
-            use os::win32::fill_utf16_buf_and_decode;
+            use os::windows::fill_utf16_buf_and_decode;
             fill_utf16_buf_and_decode(|buf, sz| {
                 libc::GetModuleFileNameW(0u as libc::DWORD, buf, sz)
             }).map(|s| s.into_string().into_bytes())
@@ -1315,7 +1315,7 @@ pub fn page_size() -> uint {
 
 /// A memory mapped file or chunk of memory. This is a very system-specific
 /// interface to the OS's memory mapping facilities (`mmap` on POSIX,
 /// `VirtualAlloc`/`CreateFileMapping` on win32). It makes no attempt at
 /// abstracting platform differences, besides in error values returned. Consider
 /// yourself warned.
 ///
@@ -1385,7 +1385,7 @@ pub enum MapError {
     ErrZeroLength,
     /// Unrecognized error. The inner value is the unrecognized errno.
     ErrUnknown(int),
     /// ## The following are win32-specific
     ///
     /// Unsupported combination of protection flags
     /// (`MapReadable`/`MapWritable`/`MapExecutable`).
@@ -1843,14 +1843,13 @@ pub mod consts {
 }
 
 #[cfg(target_os = "windows")]
-#[cfg(stage0, target_os = "win32")] // NOTE: Remove after snapshot
 pub mod consts {
     pub use os::arch_consts::ARCH;
 
     pub static FAMILY: &'static str = "windows";
 
     /// A string describing the specific operating system in use: in this
-    /// case, `win32`.
+    /// case, `windows`.
     pub static SYSNAME: &'static str = "windows";
 
     /// Specifies the filename prefix used for shared libraries on this
@@ -1315,7 +1315,7 @@ pub fn page_size() -> uint {
 /// A memory mapped file or chunk of memory. This is a very system-specific
 /// interface to the OS's memory mapping facilities (`mmap` on POSIX,
-/// `VirtualAlloc`/`CreateFileMapping` on win32). It makes no attempt at
+/// `VirtualAlloc`/`CreateFileMapping` on Windows). It makes no attempt at
 /// abstracting platform differences, besides in error values returned. Consider
 /// yourself warned.
@@ -1385,7 +1385,7 @@ pub enum MapError {
     /// Unrecognized error. The inner value is the unrecognized errno.
     ErrUnknown(int),
-    /// ## The following are win32-specific
+    /// ## The following are Windows-specific
     ///
     /// Unsupported combination of protection flags